import rhinoscriptsyntax as rs
import math

srf = rs.GetObjects("Select Surface", 8)
nRows = rs.GetInteger("Panels in X direction")
nColumns = rs.GetInteger("Panels in Y direction")

rs.SelectObject(srf)

#use this command to force the U and V coordinates of our surface to go from 0 to nRows and nColumns
#a space within the quotations is analogous to the Return button!
#the - before the command name means we're gonna provide its arguments here in-line
rs.Command("-Reparameterize 0. "+str(nRows)+" 0. "+str(nColumns))

U = rs.SurfaceDomain(srf,0);
V = rs.SurfaceDomain(srf,1);

pts = {}

for i in range(0,nRows+1):
    for j in range(0,nColumns+1):
        pts[(i,j)] = rs.EvaluateSurface(srf,i,j)
        #print(pts[(i,j)])

for i in range(0,nRows):
    for j in range(0,nColumns):
        srfPanel = rs.AddSrfPt([ pts[(i,j)],pts[(i+1,j)],pts[(i+1,j+1)],pts[(i,j+1)]])
        #return the center of this panel
        srfPanelCent = rs.SurfaceAreaCentroid(srfPanel)
        #create a curve from the panel's borders
        srfCrv = rs.DuplicateEdgeCurves(srfPanel)
        srfCrv = rs.JoinCurves(srfCrv,True)
        #this returns the panel center in U V coordinates
        uvParam = rs.SurfaceClosestPoint(srf,srfPanelCent[0])
        vectNormal = rs.SurfaceNormal(srf,uvParam)
        #vectNormal = rs.VectorScale(vectNormal, srfPanelCent[0][2])
        ptAdd = rs.PointAdd(srfPanelCent[0],vectNormal)
        rs.ExtrudeCurveStraight(srfCrv[0],srfPanelCent[0], ptAdd)